.. _head_pose.nose_stability:

Nose Stability
==============

.. automodule:: eyetrace.head_pose.nose_stability
   :members:
   :undoc-members:
   :show-inheritance:

Measures the stability of the nose tip position over time as an indicator of
head movement. Returns the variance of nose coordinates across a sequence.